@@ -1,6 +1,6 @@
 ;;; cider-browse-ns.el --- CIDER namespace browser  -*- lexical-binding: t; -*-
 
-;; Copyright © 2014-2025 John Andrews, Bozhidar Batsov and CIDER contributors
+;; Copyright © 2014-2026 John Andrews, Bozhidar Batsov and CIDER contributors
 
 ;; Author: John Andrews <john.m.andrews@gmail.com>
 
@@ -62,7 +62,7 @@
 
 Available options include `private', `test', `macro', `function', and
 `var'."
-  :type 'list
+  :type '(repeat symbol)
   :package-version '(cider . "1.4.0"))
 
 (defconst cider-browse-ns-buffer "*cider-ns-browser*")
@@ -268,7 +268,7 @@ list of items."
 (defun cider-browse-ns--render-items (items)
   "Render the nrepl-dict ITEMS to the browse-ns buffer."
   (let* ((max-length (cider-browse-ns--column-width items)))
-    (cl-labels
+    (cl-flet
         ((keys-from-pred
           (pred items)
           (nrepl-dict-keys (nrepl-dict-filter (lambda (_ var-meta)
@@ -455,7 +455,7 @@ var-meta map."
 
 (defun cider-browse-ns--thing-at-point ()
   "Get the thing at point.
-Return a list of the type ('ns or 'var) and the value."
+Return a list of the type (`ns' or `var') and the value."
   (let ((ns-p (get-text-property (point) 'ns))
         (line (car (split-string (string-trim (thing-at-point 'line)) " "))))
     (if (or ns-p (string-match "\\." line))
