@@ -1,7 +1,7 @@
 ;;; cider-repl.el --- CIDER REPL mode interactions -*- lexical-binding: t -*-
 
-;; Copyright © 2012-2025 Tim King, Phil Hagelberg, Bozhidar Batsov
-;; Copyright © 2013-2025 Bozhidar Batsov, Artur Malabarba and CIDER contributors
+;; Copyright © 2012-2026 Tim King, Phil Hagelberg, Bozhidar Batsov
+;; Copyright © 2013-2026 Bozhidar Batsov, Artur Malabarba and CIDER contributors
 ;;
 ;; Author: Tim King <kingtim@gmail.com>
 ;;         Phil Hagelberg <technomancy@gmail.com>
@@ -335,7 +335,7 @@ fully initialized."
 PARAM-TUPLES are tuples of (param-key description) or (param-key
 description transform) where transform is called with the param-value if
 present."
-  (cl-labels
+  (cl-flet
       ((emit-comment
         (contents)
         (insert-before-markers
@@ -636,7 +636,7 @@ the input stream may block the whole colorization process."
                 (let* ((sgr-end-pos (match-end 0))
                        (fragment-matches-whole? (or (= sgr-end-pos 0)
                                                     (= sgr-end-pos (length fragment)))))
-                  (when (not fragment-matches-whole?)
+                  (unless fragment-matches-whole?
                     ;; Definitely not an partial SGR seq, flush it out of
                     ;; `ansi-color-context'.
                     t)))))))
@@ -1102,7 +1102,7 @@ If NEWLINE is true then add a newline at the end of the input."
           (add-text-properties cider-repl-input-start-mark
                                (point)
                                `(cider-old-input
-                                 ,(cl-incf cider-repl-old-input-counter))))
+                                 ,(setq cider-repl-old-input-counter (1+ cider-repl-old-input-counter)))))
         (unless cider-repl-use-clojure-font-lock
           (let ((overlay (make-overlay cider-repl-input-start-mark end)))
             ;; These properties are on an overlay so that they won't be taken
@@ -1145,7 +1145,7 @@ are not balanced."
 If REPLACE is non-nil the current input is replaced with the old
 input; otherwise the new input is appended.  The old input has the
 text property `cider-old-input'."
-  (cl-multiple-value-bind (beg end) (cider-property-bounds 'cider-old-input)
+  (pcase-let ((`(,beg ,end) (cider-property-bounds 'cider-old-input)))
     (let ((old-input (buffer-substring beg end)) ;;preserve
           ;;properties, they will be removed later
           (offset (- (point) beg)))
@@ -1343,7 +1343,7 @@ case."
   "Workhorse for getting locref at point.
 REG-LIST is an entry in `cider-locref-regexp-alist'."
   (beginning-of-line)
-  (when (re-search-forward (nth 1 reg-list) (point-at-eol) t)
+  (when (re-search-forward (nth 1 reg-list) (line-end-position) t)
     (let ((ix-highlight (or (nth 2 reg-list) 0))
           (ix-var (nth 3 reg-list))
           (ix-file (nth 4 reg-list))
@@ -1369,7 +1369,7 @@ for locref look up."
     (goto-char (or pos (point)))
     ;; Regexp lookup on long lines can result in significant hangs #2532. We
     ;; assume that lines longer than 300 don't contain source references.
-    (when (< (- (point-at-eol) (point-at-bol)) 300)
+    (when (< (- (line-end-position) (line-beginning-position)) 300)
       (seq-some (lambda (rl) (cider--locref-at-point-1 rl))
                 cider-locref-regexp-alist))))
 
@@ -1471,9 +1471,10 @@ Empty strings and duplicates are ignored."
 Search in DIRECTION for REGEXP.
 Return -1 resp the length of the history if no item matches."
   ;; Loop through the history list looking for a matching line
-  (let* ((step (cl-ecase direction
-                 (forward -1)
-                 (backward 1)))
+  (let* ((step (pcase direction
+                 ('forward -1)
+                 ('backward 1)
+                 (_ (error "Invalid direction: %s" direction))))
          (history cider-repl-input-history)
          (len (length history)))
     (cl-loop for pos = (+ start-pos step) then (+ pos step)
@@ -1483,7 +1484,7 @@ Return -1 resp the length of the history if no item matches."
 
 (defun cider-repl--history-replace (direction &optional regexp)
   "Replace the current input with the next line in DIRECTION.
-DIRECTION is 'forward' or 'backward' (in the history list).
+DIRECTION is `forward' or `backward' (in the history list).
 If REGEXP is non-nil, only lines matching REGEXP are considered."
   (setq cider-repl-history-pattern regexp)
   (let* ((min-pos -1)
@@ -1597,7 +1598,7 @@ It does not yet set the input history."
 (defun cider-repl--find-dir-for-history ()
   "Find the first suitable directory to store the project's history."
   (seq-find
-   (lambda (dir) (and (not (null dir)) (not (tramp-tramp-file-p dir))))
+   (lambda (dir) (and dir (not (tramp-tramp-file-p dir))))
    (list nrepl-project-dir (clojure-project-dir) default-directory)))
 
 (defun cider-repl-history-load (&optional filename)
@@ -1635,7 +1636,7 @@ Currently coding system for writing the contents is hardwired to
 utf-8-unix."
   (let* ((end (min (length cider-repl-input-history) cider-repl-history-size))
          ;; newest items are at the beginning of the list, thus 0
-         (hist (cl-subseq cider-repl-input-history 0 end)))
+         (hist (seq-subseq cider-repl-input-history 0 end)))
     (cond
      ((file-writable-p filename)
       (let ((print-length nil) (print-level nil))
@@ -1854,7 +1855,7 @@ The checking is done as follows:
 (defun cider-debug-sesman-friendly-session-p ()
   "`message's debugging information relative to friendly sessions.
 
-This is useful for when one sees 'No linked CIDER sessions'
+This is useful for when one sees \"No linked CIDER sessions\"
 in an unexpected place."
   (interactive)
   (message (prin1-to-string (mapcar (lambda (session)
@@ -2030,8 +2031,8 @@ in an unexpected place."
         (newmap (make-sparse-keymap)))
     (set-keymap-parent newmap oldmap)
     (define-key newmap (kbd "RET") nil)
-    (make-local-variable 'minor-mode-overriding-map-alist)
-    (push `(paredit-mode . ,newmap) minor-mode-overriding-map-alist)))
+    (setq-local minor-mode-overriding-map-alist
+                (cons `(paredit-mode . ,newmap) minor-mode-overriding-map-alist))))
 
 (define-derived-mode cider-repl-mode fundamental-mode "REPL"
   "Major mode for Clojure REPL interactions.
