@@ -1,7 +1,7 @@
 ;;; cider.el --- Clojure Interactive Development Environment that Rocks -*- lexical-binding: t -*-
 
-;; Copyright © 2012-2025 Tim King, Phil Hagelberg, Bozhidar Batsov
-;; Copyright © 2013-2025 Bozhidar Batsov, Artur Malabarba and CIDER contributors
+;; Copyright © 2012-2026 Tim King, Phil Hagelberg, Bozhidar Batsov
+;; Copyright © 2013-2026 Bozhidar Batsov, Artur Malabarba and CIDER contributors
 ;;
 ;; Author: Tim King <kingtim@gmail.com>
 ;;         Phil Hagelberg <technomancy@gmail.com>
@@ -14,11 +14,12 @@
 ;; Homepage: https://www.github.com/clojure-emacs/cider
 ;; Keywords: languages, clojure, cider
 ;;
-;; Package-Version: 20260116.1514
-;; Package-Revision: 31c05c0a417c
+;; Package-Version: 20260209.1258
+;; Package-Revision: ae247d88455c
 ;; Package-Requires: (
 ;;     (emacs "28")
 ;;     (clojure-mode "5.19")
+;;     (compat "30")
 ;;     (parseedn "1.2.1")
 ;;     (queue "0.2")
 ;;     (spinner "1.7")
@@ -104,10 +105,10 @@
 (require 'sesman)
 (require 'package)
 
-(defconst cider-version "1.21.0-snapshot"
+(defconst cider-version "1.22.0-snapshot"
   "The current version of CIDER.")
 
-(defconst cider-codename "Lanzarote"
+(defconst cider-codename "Gràcia"
   "Codename used to denote stable releases.")
 
 (defcustom cider-lein-command
@@ -115,38 +116,12 @@
   "The command used to execute Leiningen."
   :type 'string)
 
-(defcustom cider-lein-global-options
-  nil
-  "Command global options used to execute Leiningen (e.g.: -o for offline)."
-  :type 'string
-  :safe #'stringp)
-
 (defcustom cider-lein-parameters
   "repl :headless :host localhost"
   "Params passed to Leiningen to start an nREPL server via `cider-jack-in'."
   :type 'string
   :safe #'stringp)
 
-(defcustom cider-boot-command
-  "boot"
-  "The command used to execute Boot."
-  :type 'string
-  :package-version '(cider . "0.9.0"))
-
-(defcustom cider-boot-global-options
-  nil
-  "Command global options used to execute Boot (e.g.: -c for checkouts)."
-  :type 'string
-  :safe #'stringp
-  :package-version '(cider . "0.14.0"))
-
-(defcustom cider-boot-parameters
-  "repl -s -b localhost wait"
-  "Params passed to boot to start an nREPL server via `cider-jack-in'."
-  :type 'string
-  :safe #'stringp
-  :package-version '(cider . "0.9.0"))
-
 (defcustom cider-clojure-cli-command
   (if (and (eq system-type 'windows-nt)
            (null (executable-find "clojure")))
@@ -160,13 +135,6 @@ default to \"powershell\"."
   :safe #'stringp
   :package-version '(cider . "0.17.0"))
 
-(defcustom cider-clojure-cli-global-options
-  nil
-  "Command line options used to execute clojure with tools.deps."
-  :type 'string
-  :safe #'stringp
-  :package-version '(cider . "0.17.0"))
-
 (defcustom cider-clojure-cli-parameters
   nil
   "Params passed to clojure cli to start an nREPL server via `cider-jack-in'."
@@ -205,13 +173,6 @@ By default we favor the project-specific shadow-cljs over the system-wide."
   :safe #'stringp
   :package-version '(cider . "0.17.0"))
 
-(defcustom cider-shadow-cljs-global-options
-  ""
-  "Command line options used to execute shadow-cljs (e.g.: -v for verbose mode)."
-  :type 'string
-  :safe #'stringp
-  :package-version '(cider . "0.17.0"))
-
 (defcustom cider-shadow-cljs-parameters
   "server"
   "Params passed to shadow-cljs to start an nREPL server via `cider-jack-in'."
@@ -226,13 +187,6 @@ By default we favor the project-specific shadow-cljs over the system-wide."
   :safe #'stringp
   :package-version '(cider . "0.10.0"))
 
-(defcustom cider-gradle-global-options
-  ""
-  "Command line options used to execute Gradle (e.g.: -m for dry run)."
-  :type 'string
-  :safe #'stringp
-  :package-version '(cider . "0.14.0"))
-
 (defcustom cider-gradle-parameters
   "clojureRepl"
   "Params passed to gradle to start an nREPL server via `cider-jack-in'."
@@ -247,13 +201,6 @@ By default we favor the project-specific shadow-cljs over the system-wide."
   :safe #'stringp
   :package-version '(cider . "1.2.0"))
 
-(defcustom cider-babashka-global-options
-  nil
-  "Command line options used to execute Babashka."
-  :type 'string
-  :safe #'stringp
-  :package-version '(cider . "1.2.0"))
-
 (defcustom cider-babashka-parameters
   "nrepl-server localhost:0"
   "Params passed to babashka to start an nREPL server via `cider-jack-in'."
@@ -268,13 +215,6 @@ By default we favor the project-specific shadow-cljs over the system-wide."
   :safe #'stringp
   :package-version '(cider . "1.6.0"))
 
-(defcustom cider-nbb-global-options
-  nil
-  "Command line options used to execute nbb."
-  :type 'string
-  :safe #'stringp
-  :package-version '(cider . "1.6.0"))
-
 (defcustom cider-nbb-parameters
   "nrepl-server"
   "Params passed to nbb to start an nREPL server via `cider-jack-in'."
@@ -299,17 +239,6 @@ By default we favor the project-specific shadow-cljs over the system-wide."
   :safe #'stringp
   :package-version '(cider . "1.14.0"))
 
-(make-obsolete-variable 'cider-lein-global-options 'cider-lein-parameters "1.8.0")
-(make-obsolete-variable 'cider-boot-command nil "1.8.0")
-(make-obsolete-variable 'cider-boot-parameters nil "1.8.0")
-(make-obsolete-variable 'cider-boot-global-options nil "1.8.0")
-(make-obsolete-variable 'cider-clojure-cli-global-options 'cider-clojure-cli-parameters "1.8.0")
-(make-obsolete-variable 'cider-shadow-cljs-global-options 'cider-shadow-cljs-parameters "1.8.0")
-(make-obsolete-variable 'cider-gradle-global-options 'cider-gradle-parameters "1.8.0")
-(make-obsolete-variable 'cider-babashka-global-options 'cider-babashka-parameters "1.8.0")
-(make-obsolete-variable 'cider-nbb-global-options 'cider-nbb-parameters "1.8.0")
-(make-obsolete-variable 'cider-enrich-classpath nil "1.19.0")
-
 (defcustom cider-jack-in-default
   (if (executable-find "clojure") 'clojure-cli 'lein)
   "The default tool to use when doing `cider-jack-in' outside a project.
@@ -320,7 +249,6 @@ As the Clojure CLI is bundled with Clojure itself, it's the default.
 In the absence of the Clojure CLI (e.g. on Windows), we fallback
 to Leiningen."
   :type '(choice (const lein)
-                 (const boot)
                  (const clojure-cli)
                  (const shadow-cljs)
                  (const gradle)
@@ -340,7 +268,6 @@ is indicated by the variable if present.  Note, this is only when CIDER
 cannot decide which of many build systems to use and will never override a
 command when there is no ambiguity."
   :type '(choice (const lein)
-                 (const boot)
                  (const clojure-cli)
                  (const shadow-cljs)
                  (const gradle)
@@ -353,7 +280,7 @@ command when there is no ambiguity."
 
 (defcustom cider-allow-jack-in-without-project 'warn
   "Controls what happens when doing `cider-jack-in' outside a project.
-When set to 'warn you'd prompted to confirm the command.
+When set to `warn' (default) you'd prompted to confirm the command.
 When set to t `cider-jack-in' will quietly continue.
 When set to nil `cider-jack-in' will fail."
   :type '(choice (const :tag "always" t)
@@ -431,7 +358,7 @@ The plist supports the following keys
 
 - :cmd a plist of instructions how to invoke the jack in command, with keys
 
-  - :jack-in-type 'clj to start a clj repl and 'cljs for a cljs repl.
+  - :jack-in-type `clj' to start a clj repl and `cljs' for a cljs repl.
 
   - &rest the same set of params supported by the `cider-jack-in-clj' and
     `cider-jack-in-cljs' commands.")
@@ -454,11 +381,6 @@ The plist supports the following keys
     ('basilisp    cider-basilisp-command)
     (_            (user-error "Unsupported project type `%S'" project-type))))
 
-(defcustom cider-enrich-classpath nil
-  "Removed."
-  :type 'boolean
-  :safe #'booleanp)
-
 (defun cider-jack-in-resolve-command (project-type)
   "Determine the resolved file path to `cider-jack-in-command'.
 Throws an error if PROJECT-TYPE is unknown."
@@ -485,18 +407,6 @@ Throws an error if PROJECT-TYPE is unknown."
     ('basilisp (cider--resolve-command cider-basilisp-command))
     (_ (user-error "Unsupported project type `%S'" project-type))))
 
-(defun cider-jack-in-global-options (project-type)
-  "Determine the command line options for `cider-jack-in' for the PROJECT-TYPE."
-  (pcase project-type
-    ('lein        cider-lein-global-options)
-    ('clojure-cli cider-clojure-cli-global-options)
-    ('babashka    cider-babashka-global-options)
-    ('shadow-cljs cider-shadow-cljs-global-options)
-    ('gradle      cider-gradle-global-options)
-    ('nbb         cider-nbb-global-options)
-    ('basilisp    nil)
-    (_            (user-error "Unsupported project type `%S'" project-type))))
-
 (defun cider-jack-in-params (project-type)
   "Determine the commands params for `cider-jack-in' for the PROJECT-TYPE."
   ;; The format of these command-line strings must consider different shells,
@@ -700,16 +610,14 @@ ClojureNRepl task."
              middlewares
              " "))
 
-(defun cider-gradle-jack-in-dependencies (global-opts params dependencies middlewares)
+(defun cider-gradle-jack-in-dependencies (params dependencies middlewares)
   "Create gradle jack in dependencies.
-Does so by concatenating GLOBAL-OPTS, DEPENDENCIES,
-and MIDDLEWARES.  GLOBAL-OPTS and PARAMS are taken as-is.
+Does so by concatenating PARAMS, DEPENDENCIES,
+and MIDDLEWARES.  PARAMS are taken as-is.
 DEPENDENCIES are translated into Gradle's typical
 group:artifact:version notation and MIDDLEWARES are
 prepared as arguments to Clojurephant's ClojureNRepl task."
-  (concat global-opts
-          (unless (seq-empty-p global-opts) " ")
-          (when cider-enable-nrepl-jvmti-agent
+  (concat (when cider-enable-nrepl-jvmti-agent
             "-Pjdk.attach.allowAttachSelf ")
           (cider--gradle-jack-in-property (append (cider--jack-in-required-dependencies) dependencies))
           " "
@@ -730,13 +638,11 @@ of EXCLUSIONS can be provided as well.  The returned
 string is quoted for passing as argument to an inferior shell."
   (shell-quote-argument (format "[%s %S%s]" (car list) (cadr list) (cider--lein-artifact-exclusions exclusions))))
 
-(defun cider-lein-jack-in-dependencies (global-opts params dependencies dependencies-exclusions lein-plugins &optional lein-middlewares)
+(defun cider-lein-jack-in-dependencies (params dependencies dependencies-exclusions lein-plugins &optional lein-middlewares)
   "Create lein jack-in dependencies.
-Does so by concatenating GLOBAL-OPTS, DEPENDENCIES, with DEPENDENCIES-EXCLUSIONS
+Does so by concatenating DEPENDENCIES, with DEPENDENCIES-EXCLUSIONS
 removed, LEIN-PLUGINS, LEIN-MIDDLEWARES and finally PARAMS."
   (concat
-   global-opts
-   (unless (seq-empty-p global-opts) " ")
    (mapconcat #'identity
               (append (seq-map (lambda (dep)
                                  (let ((exclusions (cadr (assoc (car dep) dependencies-exclusions))))
@@ -804,12 +710,12 @@ rules to quote it."
             (concat ":" aliases)))
       "")))
 
-(defun cider-clojure-cli-jack-in-dependencies (global-options params dependencies &optional command)
+(defun cider-clojure-cli-jack-in-dependencies (params dependencies &optional command)
   "Create Clojure tools.deps jack-in dependencies.
-Does so by concatenating DEPENDENCIES, PARAMS and GLOBAL-OPTIONS into a
-suitable `clojure` invocation and quoting, also accounting for COMMAND if
-provided.  The main is placed in an inline alias :cider/nrepl so that if
-your aliases contain any mains, the cider/nrepl one will be the one used."
+Does so by concatenating DEPENDENCIES and PARAMS into a suitable `clojure`
+invocation and quoting, also accounting for COMMAND if provided.  The main
+is placed in an inline alias :cider/nrepl so that if your aliases contain
+any mains, the cider/nrepl one will be the one used."
   (let* ((all-deps (thread-last dependencies
                                 (append (cider--jack-in-required-dependencies))
                                 ;; Duplicates are never OK since they would result in
@@ -837,20 +743,16 @@ your aliases contain any mains, the cider/nrepl one will be the one used."
                          "")
                        main-opts))
          (deps-quoted (cider--shell-quote-argument deps command)))
-    (format "%s-Sdeps %s -M%s:cider/nrepl%s"
-            ;; TODO: global-options are deprecated and should be removed in CIDER 2.0
-            (if global-options (format "%s " global-options) "")
+    (format "-Sdeps %s -M%s:cider/nrepl%s"
             deps-quoted
             (cider--combined-aliases)
             (if params (format " %s" params) ""))))
 
-(defun cider-shadow-cljs-jack-in-dependencies (global-opts params dependencies)
+(defun cider-shadow-cljs-jack-in-dependencies (params dependencies)
   "Create shadow-cljs jack-in deps.
-Does so by concatenating GLOBAL-OPTS, DEPENDENCIES finally PARAMS."
+Does so by concatenating PARAMS and DEPENDENCIES."
   (let ((dependencies (append (cider--jack-in-required-dependencies) dependencies)))
     (concat
-     global-opts
-     (unless (seq-empty-p global-opts) " ")
      (mapconcat #'identity
                 (seq-map (lambda (dep) (format "-d %s:%s" (car dep) (cadr dep))) dependencies)
                 " ")
@@ -874,8 +776,8 @@ See also `cider-jack-in-auto-inject-clojure'."
               dependencies))
     dependencies))
 
-(defun cider-inject-jack-in-dependencies (global-opts params project-type &optional command)
-  "Return GLOBAL-OPTS and PARAMS with injected REPL dependencies.
+(defun cider-inject-jack-in-dependencies (params project-type &optional command)
+  "Return PARAMS with injected REPL dependencies.
 These are set in `cider-jack-in-dependencies', `cider-jack-in-lein-plugins'
 and `cider-jack-in-nrepl-middlewares' are injected from the CLI according
 to the used PROJECT-TYPE, and COMMAND if provided.  Eliminates the need for
@@ -883,7 +785,6 @@ hacking profiles.clj for supporting CIDER with its nREPL middleware and
 dependencies."
   (pcase project-type
     ('lein (cider-lein-jack-in-dependencies
-            global-opts
             params
             (cider-add-clojure-dependencies-maybe
              (append `(("nrepl/nrepl" ,cider-injected-nrepl-version)) cider-jack-in-dependencies))
@@ -891,30 +792,21 @@ dependencies."
             (cider-jack-in-normalized-lein-plugins)
             cider-jack-in-lein-middlewares))
     ('clojure-cli (cider-clojure-cli-jack-in-dependencies
-                   global-opts
                    params
                    (cider-add-clojure-dependencies-maybe
                     cider-jack-in-dependencies)
                    command))
-    ('babashka (concat
-                global-opts
-                (unless (seq-empty-p global-opts) " ")
-                params))
+    ('babashka params)
     ('shadow-cljs (cider-shadow-cljs-jack-in-dependencies
-                   global-opts
                    params
                    (cider-add-clojure-dependencies-maybe
                     cider-jack-in-dependencies)))
     ('gradle (cider-gradle-jack-in-dependencies
-              global-opts
               params
               (cider-add-clojure-dependencies-maybe
                cider-jack-in-dependencies)
               (cider-jack-in-normalized-nrepl-middlewares)))
-    ('nbb (concat
-           global-opts
-           (unless (seq-empty-p global-opts) " ")
-           params))
+    ('nbb params)
     ('basilisp params)
     (_ (error "Unsupported project type `%S'" project-type))))
 
@@ -1185,7 +1077,6 @@ you're working on."
                  (const :tag "Browser"  browser)
                  (const :tag "Node"     node)
                  (const :tag "Weasel"   weasel)
-                 (const :tag "Boot"     boot)
                  (const :tag "Shadow"   shadow)
                  (const :tag "Shadow w/o Server" shadow-select)
                  (const :tag "Krell"    krell)
@@ -1342,7 +1233,7 @@ double prefix prompt for all these parameters."
 (defun cider-jack-in-cljs (params)
   "Start an nREPL server for the current project and connect to it.
 PARAMS is a plist optionally containing :project-dir, :jack-in-cmd and
-:cljs-repl-type (e.g. 'shadow, 'node, 'figwheel, etc).
+:cljs-repl-type (e.g. `shadow', `node', `figwheel', etc).
 
 With the prefix argument,
 allow editing of the jack in command; with a double prefix prompt for all
@@ -1368,7 +1259,7 @@ these parameters."
 (defun cider-jack-in-clj&cljs (&optional params soft-cljs-start)
   "Start an nREPL server and connect with clj and cljs REPLs.
 PARAMS is a plist optionally containing :project-dir, :jack-in-cmd and
-:cljs-repl-type (e.g. 'shadow, 'node, 'fighweel, etc).
+:cljs-repl-type (e.g. `shadow', `node', `figwheel', etc).
 
 With the prefix argument, allow for editing of the jack in command;
 with a double prefix prompt for all these parameters.
@@ -1422,8 +1313,8 @@ server is created."
 ;;;###autoload
 (defun cider-connect-sibling-cljs (params &optional other-repl)
   "Create a ClojureScript REPL with the same server as OTHER-REPL.
-PARAMS is a plist optionally containing :cljs-repl-type (e.g. 'node,
-'figwheel, 'shadow, etc).
+PARAMS is a plist optionally containing :cljs-repl-type (e.g. `node',
+`figwheel', `shadow', etc).
 
 All other parameters are inferred from the OTHER-REPL.
 OTHER-REPL defaults to `cider-current-repl' but in programs can also be a
@@ -1503,7 +1394,7 @@ their supplied or default values."
 (defun cider-connect-cljs (&optional params)
   "Initialize a ClojureScript connection to an nREPL server.
 PARAMS is a plist optionally containing :host, :port, :project-dir and
-:cljs-repl-type (e.g. 'shadow, 'node, 'figwheel, etc).
+:cljs-repl-type (e.g. `shadow', `node', `figwheel', etc).
 If nil, use the default parameters in `cider-connect-default-params' or
 `cider-connect-default-cljs-params'.
 
@@ -1527,7 +1418,7 @@ their supplied or default values."
 (defun cider-connect-clj&cljs (params &optional soft-cljs-start)
   "Initialize a Clojure and ClojureScript connection to an nREPL server.
 PARAMS is a plist optionally containing :host, :port, :project-dir and
-:cljs-repl-type (e.g. 'shadow, 'node, 'figwheel, etc).
+:cljs-repl-type (e.g. `shadow', `node', `figwheel', etc).
 If nil, use the default parameters in `cider-connect-default-params' and
 `cider-connect-default-cljs-params'.
 
@@ -1665,8 +1556,6 @@ PARAMS is a plist with the following keys (non-exhaustive list)
                                (cider-project-type project-dir)))
              (command (cider-jack-in-command project-type))
              (command-resolved (cider-jack-in-resolve-command project-type))
-             ;; TODO: global-options are deprecated and should be removed in CIDER 2.0
-             (command-global-opts (cider-jack-in-global-options project-type))
              (command-params (cider-jack-in-params project-type)))
         (if command-resolved
             (with-current-buffer (or (plist-get params :--context-buffer)
@@ -1677,7 +1566,7 @@ PARAMS is a plist with the following keys (non-exhaustive list)
                                                       'cider--jack-in-nrepl-params-history)
                                        command-params))
                      (cmd-params (if cider-inject-dependencies-at-jack-in
-                                     (cider-inject-jack-in-dependencies command-global-opts command-params
+                                     (cider-inject-jack-in-dependencies command-params
                                                                         project-type command)
                                    command-params)))
                 (if (or project-dir cider-allow-jack-in-without-project)
@@ -1817,10 +1706,7 @@ canceled the action, signal quit."
 (defun cider--ssh-hosts ()
   "Retrieve all ssh host from local configuration files."
   (seq-map (lambda (s) (list (replace-regexp-in-string ":$" "" s)))
-           ;; `tramp-completion-mode' is obsoleted in 26
-           (cl-progv (if (version< emacs-version "26")
-                         '(tramp-completion-mode)
-                       '(non-essential)) '(t)
+           (let ((non-essential t))
              (tramp-completion-handle-file-name-all-completions "" "/ssh:"))))
 
 (defun cider--completing-read-host (hosts)
@@ -1835,13 +1721,9 @@ Return a list of the form (HOST PORT), where PORT can be nil."
     (if (= 3 (length host)) (cdr host) host)))
 
 (defun cider--tramp-file-name (vec)
-  "A simple compatibility wrapper around `make-tramp-file-name'.
-Tramp version starting 26.1 is using a `cl-defstruct' rather than vanilla VEC."
-  (if (version< emacs-version "26.1")
-      vec
-    (with-no-warnings
-      (make-tramp-file-name :method (elt vec 0)
-                            :host   (elt vec 2)))))
+  "Create a tramp file name from VEC."
+  (make-tramp-file-name :method (elt vec 0)
+                        :host   (elt vec 2)))
 
 (defcustom cider-infer-remote-nrepl-ports nil
   "When true, cider will use ssh to try to infer nREPL ports on remote hosts."
